package Bundle::SNMP::Monitor;

$VERSION = '0.01';

1;

__END__

=head1 NAME

Bundle::SNMP::Monitor - A bundle to install the SNMP Monitor.


=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::SNMP::Monitor'


=head1 CONTENTS

Data::Dumper

SNMP 1.7

Mail::Internet 1.32

DBI

DBD::mysql

IO::AtomicFile

Bundle::HTML::EP 0.1125

SNMP::Monitor

=head1 DESCRIPTION

This bundle defines all reqreq modules for SNMP::Monitor.


=head1 AUTHOR AND COPYRIGHT

This module is Copyright (C) 1998 by

    Jochen Wiedmann
    Am Eisteich 9
    72555 Metzingen
    Germany

    Phone: +49 7123 14887
    Email: joe@ispsoft.de

All rights reserved.

You may distribute this module under the terms of either the GNU General
Public License or the Artistic License, as specified in the Perl README file.


=head1 SEE ALSO

L<SNMP::Monitor(3)>

=cut
